.. highlight:: shell

============
Installation
============


Stable release
--------------
.. |pipimage| image:: https://img.shields.io/pypi/v/pairwisedist.svg
        :target: https://pypi.python.org/pypi/pairwisedist

current version: |pipimage|

To install *pairwisedist*, run this command in your terminal:

.. code-block:: console

    $ pip install pairwisedist





This is the preferred method to install sRNA analysis pipeline, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The source code for pairwisedist can be downloaded from the `Github repository`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/GuyTeichman/pairwisedist

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/GuyTeichman/pairwisedist/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repository: https://github.com/GuyTeichman/pairwisedist
.. _tarball: https://github.com/GuyTeichman/pairwisedist/tarball/master
